@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.031-5-gad6e3a0
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.032-8-g54283e6
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 
-our $VERSION = '0.032';
+our $VERSION = '0.033';
 
 use Moose;
 with
@@ -246,6 +246,9 @@ my %sub_prereqs = (
         'Module::Metadata' => '0',      # core since perl 5.013009
         'CPAN::Meta::Requirements' => '2.120620',   # core since perl 5.015007
     },
+    is_miniperl => {
+        'DynaLoader' => '0',            # core since perl 5.000
+    },
 );
 
 # instead of including these dependencies in configure-requires, we inline
@@ -406,7 +409,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
@@ -579,6 +582,10 @@ C<can_run()> - check if we can run some command
 
 =item *
 
+C<is_miniperl()> - returns true if the current perl is miniperl (this may affect your ability to run XS code) Available since 0.033.
+
+=item *
+
 C<can_use($module [, $version ])> - checks if a module (optionally, at a specified version) can be loaded. (If you don't want to load the module, you should use C<< has_module >>, see below.)
 
 =for stopwords backcompat
@@ -680,6 +687,12 @@ inlining of sub content for some checks, to allow constant folding (e.g. C<$^O>
 
 =back
 
+=head1 LIMITATIONS
+
+It is not possible, given the current features of L<ExtUtils::MakeMaker>, to have dynamic prerequisites using the
+C<recommends>, C<suggests> or C<conflicts> types. (This is because these get added via the C<META_ADD> or
+C<META_MERGE> Makefile arguments, and these are ignored for the generation of F<MYMETA.json>.)
+
 =head1 SEE ALSO
 
 =over 4
